@@ -15,7 +15,7 @@ set_R_attributes = function (R, r_tol) {
   if(any(eigenR$values < 0)) {
     min_lambda = min(eigenR$values)
     eigenR$values[eigenR$values < 0] = 0
-    warning(paste0("The input correlation matrix has negative eigenvalues ",
+    warning_message(paste0("The input correlation matrix has negative eigenvalues ",
                    "(smallest one is ", min_lambda, "). The correlation ",
                    "matrix is adjusted such that these negative eigenvalues ",
                    "are now zeros. You can ignore this message, only if you ",
