@@ -141,13 +141,14 @@
 #'
 #' @references
 #' G. Wang, A. Sarkar, P. Carbonetto and M. Stephens (2020). A simple
-#'   new approach to variable selection in regression, with application
-#'   to genetic fine-mapping. \emph{Journal of the Royal Statistical
-#'   Society, Series B} \bold{82}, 1273-1300 \doi{10.1101/501114}.
+#' new approach to variable selection in regression, with application
+#' to genetic fine-mapping. \emph{Journal of the Royal Statistical
+#' Society, Series B} \bold{82}, 1273-1300 \doi{10.1101/501114}.
 #'
-#'   Y. Zou, P. Carbonetto, G. Wang and M. Stephens (2021).
-#'   Fine-mapping from summary data with the \dQuote{Sum of Single Effects}
-#'   model. \emph{bioRxiv} \doi{10.1101/2021.11.03.467167}.
+#' Y. Zou, P. Carbonetto, G. Wang, G and M. Stephens
+#' (2022). Fine-mapping from summary data with the \dQuote{Sum of
+#' Single Effects} model. \emph{PLoS Genetics} \bold{18},
+#' e1010299. \doi{10.1371/journal.pgen.1010299}.
 #'
 #' @examples
 #' set.seed(1)
@@ -231,6 +232,8 @@ susie_rss = function (z, R, n, bhat, shat, var_y,
       stop("shat cannot have zero or negative elements")
     z = bhat/shat
   }
+  if (length(z) < 1)
+    stop("Input vector z should have at least one element")
   z[is.na(z)] = 0
 
   # When n is provided, compute the PVE-adjusted z-scores.
