@@ -536,8 +536,8 @@ muffled_cov2cor = function (x)
 is_symmetric_matrix = function (x) {
   if (requireNamespace("Rfast",quietly = TRUE))
     return(Rfast::is.symmetric(x))
-  else
-    return(isSymmetric(x))
+  else 
+    return(Matrix::isSymmetric(x))
 }
 
 # Compute standard error for regression coef.
@@ -686,12 +686,12 @@ estimate_s_rss = function (z, R, n, r_tol = 1e-08, method = "null-mle") {
   }
 
   if (method == "null-mle") {
-    negloglikelihood = function(s, z, eigenld)
-      0.5 * sum(log((1-s)*eigenld$values + s)) +
-      0.5 * sum(z * eigenld$vectors %*% ((t(eigenld$vectors) *
-               (1/((1-s)*eigenld$values + s))) %*% z))
-    s = optim(0.5,fn = negloglikelihood,z = z,eigenld = eigenld,
-              method = "Brent",lower = 0,upper = 1)$par
+    negloglikelihood = function(s, ztv, d) {
+      0.5 * sum(log((1 - s) * d + s)) +
+      0.5 * tcrossprod(ztv / ((1 - s) * d + s), ztv)
+    }
+    s = optim(0.5,fn = negloglikelihood,ztv = crossprod(z, eigenld$vectors),
+              d = eigenld$values,method = "Brent",lower = 0,upper = 1)$par
   } else if (method == "null-partialmle") {
     colspace = which(eigenld$values > 0)
     if (length(colspace) == length(z))
@@ -759,7 +759,7 @@ estimate_s_rss = function (z, R, n, r_tol = 1e-08, method = "null-mle") {
 #' @importFrom ggplot2 geom_abline
 #' @importFrom ggplot2 theme_bw
 #' @importFrom ggplot2 labs
-#' @importFrom ggplot2 aes
+#' @importFrom ggplot2 aes_string
 #' @importFrom mixsqp mixsqp
 #'
 #' @examples
@@ -856,17 +856,22 @@ kriging_rss = function (z, R, n, r_tol = 1e-08,
   # Compute (log) likelihood ratios.
   logLRmix = logl1mix - logl0mix
 
-  res = data.frame(z = z,condmean = condmean,condvar = condvar,
-                   z_std_diff = z_std_diff,logLR = logLRmix)
-
-  p = ggplot(res) + geom_point(aes(y = z, x = condmean)) +
+  z          = drop(z)
+  z_std_diff = drop(z_std_diff)
+  res = data.frame(z = z,
+                   condmean = condmean,
+                   condvar = condvar,
+                   z_std_diff = z_std_diff,
+                   logLR = logLRmix)
+  p = ggplot(res,aes_string(y = "z",x = "condmean")) +
+        geom_point() +
         labs(y = "Observed z scores", x = "Expected value") +
         geom_abline(intercept = 0, slope = 1) +
         theme_bw()
   idx = which(logLRmix > 2 & abs(z) > 2)
   if (length(idx) > 0)
     p = p + geom_point(data = res[idx,],
-                       aes(y = z, x = condmean),col = "red")
+                       aes_string(y = "z", x = "condmean"),col = "red")
   return(list(plot = p,conditional_dist = res))
 }
 
@@ -924,20 +929,17 @@ compute_colstats = function (X, center = TRUE, scale = TRUE) {
 # @param X an n by p matrix of any type, e.g. sparse, dense.
 # @return a p vector of column standard deviations.
 #
-#' @importFrom Matrix rowSums
-#' @importFrom Matrix colSums
-#' @importFrom Matrix rowMeans
 #' @importFrom matrixStats colSds
+#' @importFrom Matrix summary
 compute_colSds = function(X) {
   if (is.matrix(X))
-    y = colSds(X)
+    return(colSds(X))
   else {
     n = nrow(X)
-    X = t(X)
-    X = X - rowMeans(X)
-    y = sqrt(rowSums(X^2)/(n-1))
+    Y = apply_nonzeros(X,function (u) u^2)
+    d = colMeans(Y) - colMeans(X)^2
+    return(sqrt(d*n/(n-1)))
   }
-  return(y)
 }
 
 # @title Check whether A is positive semidefinite
@@ -991,3 +993,12 @@ warning_message = function(..., style=c("warning", "hint")) {
     message(alert("HINT:"), " ", ...)
   }
 }
+
+# Apply operation f to all nonzeros of a sparse matrix.
+#
+#' @importFrom Matrix sparseMatrix
+#' 
+apply_nonzeros <- function (X, f) {
+  d <- summary(X)
+  return(sparseMatrix(i = d$i,j = d$j,x = f(d$x),dims = dim(X)))
+}
